@@ -20,6 +20,9 @@ parseVmOptions() {
 					APP_PATH="$APP_PATH:${LINE:5}"
 				elif [ ${LINE:0:7} == 'swtver=' ]; then
 					SWT_VERSION="${LINE:7}"
+				elif [ ${LINE:0:28} == '-Dsmartgit.linux.forceTheme=' ]; then
+					GTK_THEME=${LINE:28}
+					GTK_THEME=${GTK_THEME//[[:blank:]]/}
 				else
 					_VM_PROPERTIES="$_VM_PROPERTIES $LINE"
 				fi
@@ -130,7 +133,7 @@ _VM_OPTS=(
 	-XX:-UsePerfData                       # disable the perfdata feature
 	-XX:MaxJavaStackTraceDepth=1000000     # to prevent truncated stack traces
 	-Dsun.io.useCanonCaches=false          # disable caching of canonical file paths to increase performance
-	-XX:ErrorFile=$APP_CONFIG_DIR/24.1/hs_err_pid%p.log  # write VM crash files to this location
+	-XX:ErrorFile=$APP_CONFIG_DIR/25.1/hs_err_pid%p.log  # write VM crash files to this location
 )
 
 _MISC_OPTS=""
